==> kdevplatform-1.5.80.tar.xz: kdevplatform-1.5.80/plugins/execute/kdevexecute.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=system-run
Exec=blubb
Comment=This plugin allows running of programs with no instrumentor, ie. natively by the current host.
Comment[bg]=Тaзи приставка позволява изпълнение на програмата без основния модул, т.е. локално на текущата машина.
Comment[bs]=Ovaj dodatak omogučava pokretanje programa bez instrumentora, tj. koristeći mogučnosti trenutnog računara.
Comment[ca]=Aquest connector permet executar programes sense «instrumentor», és a dir, nativament per l'amfitrió actual.
Comment[ca@valencia]=Este connector permet executar programes sense «instrumentor», és a dir, nativament per l'amfitrió actual.
Comment[da]=Dette plugin tillader kørsel af programmer uden instrumentor dvs. nativt på det nuværende system.
Comment[de]=Dieses Modul erlaubt das Ausführen von Programmen im Kontext des Betriebssystems.
Comment[el]=Αυτό το πρόσθετο επιτρέπει την εκτέλεση προγραμμάτων χωρίς οργανωτή, πχ. εγγενώς από τον τρέχων υπολογιστή.
Comment[en_GB]=This plugin allows running of programs with no instrumentor, ie. natively by the current host.
Comment[es]=Este complemento permite ejecutar programas sin instrumentor (es decir, de forma nativa por la máquina actual).
Comment[et]=See plugin võimaldab panna programme aktiivses masinas tööle ilma instrumentaatorita, s.t loomulikult.
Comment[fi]=Tämä liitännäinen mahdollistaa ohjelmien suorittamisen ilman välikappaletta, ts. natiivisti nykyisellä tietokoneella.
Comment[fr]=Ce module externe permet le lancement de programmes sans instrumenteur, c'est-à-dire nativement par l'hôte actuel.
Comment[gl]=Este complemento permite executar programas sen instrumentador, i.e. de xeito nativo na máquina actual.
Comment[it]=Questa estensione permette l'esecuzione dei programmi senza instrumentor, vale a dire nativamente da parte dell'host attuale.
Comment[kk]=Бұл плагин көмегімен бағдарламаны тікелей назардағы хостта жегуге болады.
Comment[nb]=Dette programtillegget tillater kjøring av programmer uten instrumentering, dvs. lokalt på den gjeldende verten.
Comment[nds]=Dit Moduul föhrt Programmen ahn Utstatter ut, d.h. bloots mit den aktuellen Reekner.
Comment[nl]=Deze plugin staat het uitvoeren van programma's toe zonder hulpprogramma, dwz. van nature op de huidige host.
Comment[pl]=Wtyczka ta pozwala na uruchamianie programów bez instrumentora, np. natywnie przez obecnego hosta.
Comment[pt]=Este 'plugin' permite a execução dos programas não-instrumentalizados, i.e. nativamente pela máquina actual.
Comment[pt_BR]=Este plugin permite executar programas sem orquestrador, ou seja, nativamente pelo computador hospedeiro.
Comment[ru]=Это расширение позволяет запускать программы без инструментальной обвязки, то есть непосредственно на текущем компьютере.
Comment[sk]=Tento plugin umožňuje spustenie programov bez inštrumentora, teda natívne aktuálnym hostiteľom.
Comment[sl]=Vstavek omogoča zaganjanje programov, za katere v KDevelop ni posebnega grafičnega vmesnika.
Comment[sv]=Insticksprogrammet tillåter att program utan instrumentering körs, dvs. direkt av nuvarande värddator.
Comment[tr]=Bu eklenti, uygulamaları, kullanılan makine üzerinde, hiç bir ek araç kullanmadan doğal hali ile çalıştırmayı sağlar.
Comment[uk]=За допомогою цього додатка можна запускати програми безпосередньо на поточному вузлі.
Comment[x-test]=xxThis plugin allows running of programs with no instrumentor, ie. natively by the current host.xx
Comment[zh_CN]=此插件允许以无操作者方式运行程序，例如，当前主机的原生方式。
Comment[zh_TW]=此外掛程式允許在目前主機上執行程式。
Name=Execute Programs
Name[bg]=Изпълняване на програми
Name[bs]=Izvrši programe
Name[ca]=Executa programes
Name[ca@valencia]=Executa programes
Name[cs]=Spustit programy
Name[da]=Kør programmer
Name[de]=Programme ausführen
Name[el]=Εκτέλεση προγραμμάτων
Name[en_GB]=Execute Programs
Name[es]=Ejecutar programas
Name[et]=Programmide täitmine
Name[fi]=Suorita ohjelmia
Name[fr]=Exécuter des programmes
Name[ga]=Rith Ríomhchláir
Name[gl]=Executar programas
Name[hu]=Programok végrehajtása
Name[it]=Esegui i programmi
Name[ja]=プログラムを実行
Name[kk]=Бағдарламаларды орындау
Name[nb]=Kjør programmer
Name[nds]=Programmen utföhren
Name[nl]=Programma's uitvoeren
Name[pl]=Wykonaj programy
Name[pt]=Execução de Programas
Name[pt_BR]=Executar programa
Name[ru]=Запуск программ
Name[sk]=Spustiť programy
Name[sl]=Izvedi programe
Name[sv]=Kör program
Name[tr]=Uygulamaları Çalıştır
Name[ug]=پروگرامما ئىجرا قىلىش
Name[uk]=Виконання програм
Name[x-test]=xxExecute Programsxx
Name[zh_CN]=执行程序
Name[zh_TW]=執行程式
GenericName=Program Execution Support
GenericName[bg]=Поддръжка за изпълнение на програми
GenericName[bs]=Podrška za izvršenje programa
GenericName[ca]=Implementació d'execució de programes
GenericName[ca@valencia]=Implementació d'execució de programes
GenericName[da]=Understøttelse af kørsel af programmer
GenericName[de]=Unterstützung zur Ausführung von Programmen
GenericName[el]=Υποστήριξη εκτέλεσης προγραμμάτων
GenericName[en_GB]=Program Execution Support
GenericName[es]=Implementación de la ejecución de programas
GenericName[et]=Programmide täitmise toetus
GenericName[fi]=Ohjelman suoritustuki
GenericName[fr]=Prise en charge de l'exécution des programmes
GenericName[gl]=Soporte de execución de programas
GenericName[hu]=Programvégrehajtás támogatás
GenericName[it]=Supporto esecuzione programmi
GenericName[ja]=プログラム実行のサポート
GenericName[kk]=Бағдарламаны орындауын қолдау
GenericName[nb]=Støtte for programkjøring
GenericName[nds]=Programmutföhr-Ünnerstütten
GenericName[nl]=Ondersteuning voor uitvoeren van programma
GenericName[pl]=Obsługa wykonywania programów
GenericName[pt]=Suporte à Execução de Programas
GenericName[pt_BR]=Suporte a execução de programa
GenericName[ru]=Поддержка запуска программ
GenericName[sk]=Podpora spúšťania programov
GenericName[sl]=Podpora za izvajanje programov
GenericName[sv]=Stöd för körning av program
GenericName[tr]=Uygulama Çalıştırma Desteği
GenericName[ug]=پروگرامما ئىجرا قىلىشنى قوللاش
GenericName[uk]=Підтримка виконання програм
GenericName[x-test]=xxProgram Execution Supportxx
GenericName[zh_CN]=程序执行支持
GenericName[zh_TW]=執行程式支援
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevexecute
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevexecute
X-KDE-PluginInfo-Author=Hamish Rodda
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-Interfaces=org.kdevelop.IExecutePlugin
X-KDevelop-Mode=NoGUI

==> kdevplatform-1.5.90.tar.xz: kdevplatform-1.5.90/plugins/execute/kdevexecute.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=system-run
Exec=blubb
Comment=This plugin allows running of programs with no instrumentor, ie. natively by the current host.
Comment[bg]=Тaзи приставка позволява изпълнение на програмата без основния модул, т.е. локално на текущата машина.
Comment[bs]=Ovaj dodatak omogučava pokretanje programa bez instrumentora, tj. koristeći mogučnosti trenutnog računara.
Comment[ca]=Aquest connector permet executar programes sense «instrumentor», és a dir, nativament per a l'amfitrió actual.
Comment[ca@valencia]=Este connector permet executar programes sense «instrumentor», és a dir, nativament per l'amfitrió actual.
Comment[da]=Dette plugin tillader kørsel af programmer uden instrumentor dvs. nativt på det nuværende system.
Comment[de]=Dieses Modul erlaubt das Ausführen von Programmen im Kontext des Betriebssystems.
Comment[el]=Αυτό το πρόσθετο επιτρέπει την εκτέλεση προγραμμάτων χωρίς οργανωτή, πχ. εγγενώς από τον τρέχων υπολογιστή.
Comment[en_GB]=This plugin allows running of programs with no instrumentor, ie. natively by the current host.
Comment[es]=Este complemento permite ejecutar programas sin instrumentor (es decir, de forma nativa por la máquina actual).
Comment[et]=See plugin võimaldab panna programme aktiivses masinas tööle ilma instrumentaatorita, s.t loomulikult.
Comment[fi]=Tämä liitännäinen mahdollistaa ohjelmien suorittamisen ilman välikappaletta, ts. natiivisti nykyisellä tietokoneella.
Comment[fr]=Ce module externe permet le lancement de programmes sans instrumenteur, c'est-à-dire nativement par l'hôte actuel.
Comment[gl]=Este complemento permite executar programas sen instrumentador, i.e. de xeito nativo na máquina actual.
Comment[it]=Questa estensione permette l'esecuzione dei programmi senza instrumentor, vale a dire nativamente da parte dell'host attuale.
Comment[kk]=Бұл плагин көмегімен бағдарламаны тікелей назардағы хостта жегуге болады.
Comment[nb]=Dette programtillegget tillater kjøring av programmer uten instrumentering, dvs. lokalt på den gjeldende verten.
Comment[nds]=Dit Moduul föhrt Programmen ahn Utstatter ut, d.h. bloots mit den aktuellen Reekner.
Comment[nl]=Deze plugin staat het uitvoeren van programma's toe zonder hulpprogramma, dwz. van nature op de huidige host.
Comment[pl]=Wtyczka ta pozwala na uruchamianie programów bez instrumentora, np. natywnie przez obecnego hosta.
Comment[pt]=Este 'plugin' permite a execução dos programas não-instrumentalizados, i.e. nativamente pela máquina actual.
Comment[pt_BR]=Este plugin permite executar programas sem orquestrador, ou seja, nativamente pelo computador hospedeiro.
Comment[ru]=Это расширение позволяет запускать программы без инструментальной обвязки, то есть непосредственно на текущем компьютере.
Comment[sk]=Tento plugin umožňuje spustenie programov bez inštrumentora, teda natívne aktuálnym hostiteľom.
Comment[sl]=Vstavek omogoča zaganjanje programov, za katere v KDevelop ni posebnega grafičnega vmesnika.
Comment[sv]=Insticksprogrammet tillåter att program utan instrumentering körs, dvs. direkt av nuvarande värddator.
Comment[tr]=Bu eklenti, uygulamaları, kullanılan makine üzerinde, hiç bir ek araç kullanmadan doğal hali ile çalıştırmayı sağlar.
Comment[uk]=За допомогою цього додатка можна запускати програми безпосередньо на поточному вузлі.
Comment[x-test]=xxThis plugin allows running of programs with no instrumentor, ie. natively by the current host.xx
Comment[zh_CN]=此插件允许以无操作者方式运行程序，例如，当前主机的原生方式。
Comment[zh_TW]=此外掛程式允許在目前主機上執行程式。
Name=Execute Programs
Name[bg]=Изпълняване на програми
Name[bs]=Izvrši programe
Name[ca]=Executa programes
Name[ca@valencia]=Executa programes
Name[cs]=Spustit programy
Name[da]=Kør programmer
Name[de]=Programme ausführen
Name[el]=Εκτέλεση προγραμμάτων
Name[en_GB]=Execute Programs
Name[es]=Ejecutar programas
Name[et]=Programmide täitmine
Name[fi]=Suorita ohjelmia
Name[fr]=Exécuter des programmes
Name[ga]=Rith Ríomhchláir
Name[gl]=Executar programas
Name[hu]=Programok végrehajtása
Name[it]=Esegui i programmi
Name[ja]=プログラムを実行
Name[kk]=Бағдарламаларды орындау
Name[nb]=Kjør programmer
Name[nds]=Programmen utföhren
Name[nl]=Programma's uitvoeren
Name[pl]=Wykonaj programy
Name[pt]=Execução de Programas
Name[pt_BR]=Executar programa
Name[ru]=Запуск программ
Name[sk]=Spustiť programy
Name[sl]=Izvedi programe
Name[sv]=Kör program
Name[tr]=Uygulamaları Çalıştır
Name[ug]=پروگرامما ئىجرا قىلىش
Name[uk]=Виконання програм
Name[x-test]=xxExecute Programsxx
Name[zh_CN]=执行程序
Name[zh_TW]=執行程式
GenericName=Program Execution Support
GenericName[bg]=Поддръжка за изпълнение на програми
GenericName[bs]=Podrška za izvršenje programa
GenericName[ca]=Implementació d'execució de programes
GenericName[ca@valencia]=Implementació d'execució de programes
GenericName[da]=Understøttelse af kørsel af programmer
GenericName[de]=Unterstützung zur Ausführung von Programmen
GenericName[el]=Υποστήριξη εκτέλεσης προγραμμάτων
GenericName[en_GB]=Program Execution Support
GenericName[es]=Implementación de la ejecución de programas
GenericName[et]=Programmide täitmise toetus
GenericName[fi]=Ohjelman suoritustuki
GenericName[fr]=Prise en charge de l'exécution des programmes
GenericName[gl]=Soporte de execución de programas
GenericName[hu]=Programvégrehajtás támogatás
GenericName[it]=Supporto esecuzione programmi
GenericName[ja]=プログラム実行のサポート
GenericName[kk]=Бағдарламаны орындауын қолдау
GenericName[nb]=Støtte for programkjøring
GenericName[nds]=Programmutföhr-Ünnerstütten
GenericName[nl]=Ondersteuning voor uitvoeren van programma
GenericName[pl]=Obsługa wykonywania programów
GenericName[pt]=Suporte à Execução de Programas
GenericName[pt_BR]=Suporte a execução de programa
GenericName[ru]=Поддержка запуска программ
GenericName[sk]=Podpora spúšťania programov
GenericName[sl]=Podpora za izvajanje programov
GenericName[sv]=Stöd för körning av program
GenericName[tr]=Uygulama Çalıştırma Desteği
GenericName[ug]=پروگرامما ئىجرا قىلىشنى قوللاش
GenericName[uk]=Підтримка виконання програм
GenericName[x-test]=xxProgram Execution Supportxx
GenericName[zh_CN]=程序执行支持
GenericName[zh_TW]=執行程式支援
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevexecute
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevexecute
X-KDE-PluginInfo-Author=Hamish Rodda
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-Interfaces=org.kdevelop.IExecutePlugin
X-KDevelop-Mode=NoGUI
